# Google Image Search & Download using the API

This will fetch images using the google API and save to an images folder. You just specify the search term. eg. "cat" or "dog"

## Installation

Run the following to install:

```python
pip install gimdl
```

## Usage

```python
import gimdl
from gimdl import fetch_images

# specify what images you want to fetch
fetch_images("cat")
```

More info:</br>
https://github.com/RGGH/gimdl
